#
# spec file for package xmvn-parent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global parent xmvn
%global subname parent
Name:           %{parent}-%{subname}
Version:        4.2.0
Release:        150200.3.24.2
Summary:        XMvn Parent POM
License:        Apache-2.0
Group:          Development/Tools/Building
URL:            https://fedora-java.github.io/xmvn/
Source0:        https://github.com/fedora-java/%{parent}/releases/download/%{version}/%{parent}-%{version}.tar.xz
Patch0:         UUID.patch
Patch1:         0001-Do-not-leave-a-stray-options-file-in-the-generated-j.patch
BuildRequires:  javapackages-local
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
Provides:       %{name}-pom
Obsoletes:      %{name}-pom
BuildArch:      noarch

%description
This package provides XMvn parent POM.

%prep
%setup -q -n %{parent}-%{version}

%autopatch -p1

%pom_remove_plugin -r :maven-site-plugin

# Upstream code quality checks, not relevant when building RPMs
%pom_remove_plugin -r :apache-rat-plugin
%pom_remove_plugin -r :maven-checkstyle-plugin
%pom_remove_plugin -r :jacoco-maven-plugin

# remove dependency plugin maven-binaries execution
# we provide apache-maven by symlink
%pom_xpath_remove "pom:executions/pom:execution[pom:id[text()='maven-binaries']]"

%build

%install
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{parent}
install -pm 0644 xmvn-parent/pom.xml %{buildroot}%{_mavenpomdir}/%{parent}/%{name}.pom
%add_maven_depmap %{parent}/%{name}.pom

%files -f .mfiles
%license LICENSE NOTICE
%doc AUTHORS README.md

%changelog
* Tue Jan 30 2024 fstrba@suse.com
- Modified patch:
  * UUID.patch
    + sync with the version in our official upstream pull request
* Wed Sep 13 2023 fstrba@suse.com
- Added patch:
  * 0001-Do-not-leave-a-stray-options-file-in-the-generated-j.patch
    + Remove generated temporary file from the tree after use, make
    thus the generated javadoc more reproducible
* Wed Aug  2 2023 fstrba@suse.com
- Modified patch:
  * UUID.patch
    + try to assure unique UUID for each of the split packages.
* Mon Jul 24 2023 fstrba@suse.com
- Added patch:
  * UUID.patch
    + avoid generating random UUIDs, which makes reproducible build
    impossible (bsc#1162112)
* Wed May  3 2023 fstrba@suse.com
- Upgrade to version 4.2.0
  * Changes:
    + Make XMvn Resolver log to XMvn Logger
    + Make XMvn Subst log to XMvn Logger
    + Depend on junit-jupiter-api instead of junit-jupiter
    + Suppress deprecation warnings in MavenExtensionTest
    + Remove XMvn Connector dependency on Plexus Utils
    + Remove XMvn MOJO dependency on Plexus Utils
    + Port XMvn MOJO from Xpp3Dom to StAX
    + Update Maven to version 3.9.1
    + Don't pass duplicate --patch-module to javadoc
    + Make Javadoc MOJO respect ignoreJPMS configuration flag
    + Propagate javadoc output througt Logger
    + Remove dependency on Plexus Classworlds
    + Remove unneeded managed dependency on maven-invoker
    + Use ServiceLocator to find Logger
    + Use parametrized logging feature
    + Use XMvn Logger instead of Plexus Logger
    + Get rid of Slf4jLoggerAdapter
    + Drop support for Gossip logger
    + Move XMvn Logger to API module
    + Ignore JPMS when all modules are automatic
    + Refactor Javadoc MOJO
    + Make Javadoc not fail when no sources are found
    + Add an integration test for javadoc generation with
    module-info.java but no sources
    + Add an integration test for javadoc generation with
    Automatic-Module-Name
    + Make Javadoc MOJO work in case one of JPMS modules has no
    sources
    + Prioritize certain XMvn components over Maven components
    + Port XMvn MOJO to JSR-330
    + Refactor XMvnMojoExecutionConfigurator
    + Make builddep MOJO compatible with Maven 4
    + Port to JSR-330
    + Get rid of ModelProcessor
    + Refactor XMvnModelValidator
    + Refactor XMvnToolchainManager
    + Convert lambda to method reference
    + Improve Javadoc MOJO JPMS support
    + Add a test case for JPMS javadoc generation with remote
    dependencies
    + Add a test case for JPMS multimodule javadoc generation
    + Exclude src/test/resources-filtered/** from RAT
    + Fix scope of xmvn-mojo dependency on plexus-utils
    + --module-path not allowed with release=8
    + Mimic maven-javadoc-plugin for -source and --release
    + testJavadocJPMS needs a modular java
    + Let modello generate source 8
    + Add a jdk9+ profile to assure that we are jdk8 compatible
    + Revert "Use new Collection methods added in Java 9"
    + Revert "Update compiler source/target to JDK 11"
    + Restore possibility to build with Java 8
    + Simple implementation of toolchains
    https://github.com/fedora-java/xmvn/issues/142
    + Port to Modello 2.0.0
- Removed patches
  * 0001-Mimic-maven-javadoc-plugin-for-source-and-release.patch
  * 0001-Port-to-Maven-3.8.5.patch
  * 0001-Restore-possibility-to-build-with-Java-8.patch
  * 0001-Simple-implementation-of-toolchains-https-github.com.patch
  * 0002-Revert-Update-compiler-source-target-to-JDK-11.patch
  * 0002-module-path-not-allowed-with-release-8.patch
  * 0003-Revert-Use-new-Collection-methods-added-in-Java-9.patch
  * 0004-Add-a-jdk9-profile-to-assure-that-we-are-jdk8-compat.patch
    + Integrated upstream in this version
* Mon May 16 2022 fstrba@suse.com
- Added patch:
  * 0001-Port-to-Maven-3.8.5.patch
    + Allow buiding against unpatched maven 3.8.5
* Tue May 10 2022 fstrba@suse.com
- Upgrade to version 4.0.0
  * Changes:
    +  Bump codecov/codecov-action from 2.0.1 to 2.0.2
    +  Bump codecov/codecov-action from 1 to 2.0.1
    +  Bump commons-compress from 1.20 to 1.21 in /xmvn-parent
    +  Change logic for JPMS detection by Javadoc MOJO
    +  Fix Javadoc generation for non-JPMS project with JDK 11
    +  Remove superflous JARs from assembly
    +  Create a backup file when injecting Manifest
    +  Attach site artifacts only in site lifecycle
    +  Rename xmvn-connector-aether to xmvn-connector
    +  Use try-with-resources to avoid resource leaks
    +  Remove unused AtomicFileCounter class
    +  Update Eclipse project settings
    +  Add separate build profile for code quality tools
    +  Remove prerequisites on Maven version
    +  Drop bisect tool
    +  Move release plugins to pluginManagement
    +  Move prerequisites on Maven version to xmvn-mojo
    +  Fix javadoc warning
    +  Bump junit from 4.12 to 4.13.1 in /xmvn-it/src/test/resources/testBisect
    +  Bump slf4jVersion from 1.8.0-beta4 to 2.0.0-alpha2 in /xmvn-parent
    +  Compile everything whith --release 11
    +  Fix assembly building with Maven Checkstyle Plugin 3.1.0+
    +  Update to latest Checkstyle
    +  Format code to conform to Checkstyle 8.44
    +  Untabify Maven build files
    +  Update Maven plugin versions
    +  Drop Ivy
    +  Drop Gradle
    +  Add support for compiler release setting
    +  Fix Javadoc generation for modular projects
    +  Add JPMS check to Javadoc MOJO
    +  Add missing license headers
    +  Disable I/O write test if the build is running as root
    +  Switch to SHA-256 in CacheManager
    +  Update dependency xmlunit.assertj to xmlunit.assertj3
    +  Fixes #56 - Honour source parameter in javadoc mojo
    +  Implement XMvn toolchain manager
    +  Fix requires generation for self-depending packages
    +  Remove redundant parentheses
    +  Remove redudnant use of this
    +  Relay on implicit access modifiers of interfaces
    +  Rely on implicit boxing
    +  Make use of diamond operator
    +  [test] Use use lambda expressions for creation of DeploymentResult
    +  Remove use of deprecated StringUtils methods
    +  [test] Port tests to JUnit 5
    +  Update to latest dependencies
    +  [test] Add missing assertions about XML output
    +  Use new Collection methods added in Java 9
    +  Remove uses of deprecated Class.newInstance() method
    +  Drop artifact resolution from JAVA_HOME
    +  Update to latest Maven plugin versions
    +  Update compiler source/target to JDK 11
    +  Update Eclipse project settings
    +  Make xmvn-subst honor settings for ignoring duplicate metadata
    +  Allow removing plugins during model validation
    +  Prefer namespaced metadata when duplicates are found
* Thu Nov 21 2019 fstrba@suse.com
- Upgrade to upstream version 3.1.0
* Wed Apr  3 2019 fstrba@suse.com
- Initial packaging of xmvn-parent pom version 3.0.0
